==> haskell-ghc-lib-parser-ex-9.4.0.0-69-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-ghc-lib-parser-ex.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 ghc-lib-parser-ex
version:              9.4.0.0
visibility:           public
id:                   ghc-lib-parser-ex-9.4.0.0-7PgFFrPQ1WB5vGXGwoevjx
key:                  ghc-lib-parser-ex-9.4.0.0-7PgFFrPQ1WB5vGXGwoevjx
license:              BSD-3-Clause
copyright:            Copyright © 2020-2022 Shayne Fletcher. All rights reserved.
maintainer:           shayne@shaynefletcher.org
author:               Shayne Fletcher
homepage:             https://github.com/shayne-fletcher/ghc-lib-parser-ex#readme
synopsis:             Algorithms on GHC parse trees
description:
    Please see the README on GitHub at <https://github.com/shayne-fletcher/ghc-lib-parser-ex#readme>

category:             Development
abi:                  cc7a4d5bead9323f97864a8523fdbf3d
exposed:              True
exposed-modules:
    Language.Haskell.GhclibParserEx.Dump
    Language.Haskell.GhclibParserEx.Fixity
    Language.Haskell.GhclibParserEx.GHC.Driver.Flags
    Language.Haskell.GhclibParserEx.GHC.Driver.Session
    Language.Haskell.GhclibParserEx.GHC.Hs
    Language.Haskell.GhclibParserEx.GHC.Hs.Binds
    Language.Haskell.GhclibParserEx.GHC.Hs.Decls
    Language.Haskell.GhclibParserEx.GHC.Hs.Expr
    Language.Haskell.GhclibParserEx.GHC.Hs.ExtendInstances
    Language.Haskell.GhclibParserEx.GHC.Hs.ImpExp
    Language.Haskell.GhclibParserEx.GHC.Hs.Pat
    Language.Haskell.GhclibParserEx.GHC.Hs.Type
    Language.Haskell.GhclibParserEx.GHC.Hs.Types
    Language.Haskell.GhclibParserEx.GHC.Parser
    Language.Haskell.GhclibParserEx.GHC.Settings.Config
    Language.Haskell.GhclibParserEx.GHC.Types.Name.Reader
    Language.Haskell.GhclibParserEx.GHC.Utils.Outputable

hidden-modules:       Paths_ghc_lib_parser_ex
import-dirs:          /usr/lib/ghc-9.4.8/site-local/ghc-lib-parser-ex-9.4.0.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/ghc-lib-parser-ex-9.4.0.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/ghc-lib-parser-ex-9.4.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-ghc-lib-parser-ex
hs-libraries:         HSghc-lib-parser-ex-9.4.0.0-7PgFFrPQ1WB5vGXGwoevjx
include-dirs:
    /usr/lib/ghc-9.4.8/site-local/ghc-lib-parser-ex-9.4.0.0/include

depends:
    base-4.17.2.1 bytestring-0.11.5.3 containers-0.6.7 ghc-9.4.8
    ghc-boot-9.4.8 ghc-boot-th-9.4.8
    uniplate-1.6.13-IQXc4WPApuP8Ue74JqzZnu

haddock-interfaces:
    /usr/share/doc/haskell-ghc-lib-parser-ex/html/ghc-lib-parser-ex.haddock

haddock-html:         /usr/share/doc/haskell-ghc-lib-parser-ex/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-ghc-lib-parser-ex-9.4.0.0-70-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-ghc-lib-parser-ex.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 ghc-lib-parser-ex
version:              9.4.0.0
visibility:           public
id:                   ghc-lib-parser-ex-9.4.0.0-6rHhTJvDPWwHDXe0OzrwYj
key:                  ghc-lib-parser-ex-9.4.0.0-6rHhTJvDPWwHDXe0OzrwYj
license:              BSD-3-Clause
copyright:            Copyright © 2020-2022 Shayne Fletcher. All rights reserved.
maintainer:           shayne@shaynefletcher.org
author:               Shayne Fletcher
homepage:             https://github.com/shayne-fletcher/ghc-lib-parser-ex#readme
synopsis:             Algorithms on GHC parse trees
description:
    Please see the README on GitHub at <https://github.com/shayne-fletcher/ghc-lib-parser-ex#readme>

category:             Development
abi:                  0a79fcd6b8dd6c8514b31d82520b8695
exposed:              True
exposed-modules:
    Language.Haskell.GhclibParserEx.Dump
    Language.Haskell.GhclibParserEx.Fixity
    Language.Haskell.GhclibParserEx.GHC.Driver.Flags
    Language.Haskell.GhclibParserEx.GHC.Driver.Session
    Language.Haskell.GhclibParserEx.GHC.Hs
    Language.Haskell.GhclibParserEx.GHC.Hs.Binds
    Language.Haskell.GhclibParserEx.GHC.Hs.Decls
    Language.Haskell.GhclibParserEx.GHC.Hs.Expr
    Language.Haskell.GhclibParserEx.GHC.Hs.ExtendInstances
    Language.Haskell.GhclibParserEx.GHC.Hs.ImpExp
    Language.Haskell.GhclibParserEx.GHC.Hs.Pat
    Language.Haskell.GhclibParserEx.GHC.Hs.Type
    Language.Haskell.GhclibParserEx.GHC.Hs.Types
    Language.Haskell.GhclibParserEx.GHC.Parser
    Language.Haskell.GhclibParserEx.GHC.Settings.Config
    Language.Haskell.GhclibParserEx.GHC.Types.Name.Reader
    Language.Haskell.GhclibParserEx.GHC.Utils.Outputable

hidden-modules:       Paths_ghc_lib_parser_ex
import-dirs:          /usr/lib/ghc-9.4.8/site-local/ghc-lib-parser-ex-9.4.0.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/ghc-lib-parser-ex-9.4.0.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/ghc-lib-parser-ex-9.4.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-ghc-lib-parser-ex
hs-libraries:         HSghc-lib-parser-ex-9.4.0.0-6rHhTJvDPWwHDXe0OzrwYj
include-dirs:
    /usr/lib/ghc-9.4.8/site-local/ghc-lib-parser-ex-9.4.0.0/include

depends:
    base-4.17.2.1 bytestring-0.11.5.3 containers-0.6.7 ghc-9.4.8
    ghc-boot-9.4.8 ghc-boot-th-9.4.8
    uniplate-1.6.13-78HCiTiJiiH6ptr9yQach

haddock-interfaces:
    /usr/share/doc/haskell-ghc-lib-parser-ex/html/ghc-lib-parser-ex.haddock

haddock-html:         /usr/share/doc/haskell-ghc-lib-parser-ex/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
